@@ -1,8 +1,8 @@
 use crate::{
-    AuthenticationProof, Changes, Contact, Credential, CredentialAttribute, CredentialFragment1,
-    CredentialFragment2, CredentialOffer, CredentialPresentation, CredentialProof,
-    CredentialPublicKey, CredentialRequest, CredentialSchema, OfferId, PresentationManifest,
-    ProfileChangeEvent, ProfileIdentifier, ProofRequestId,
+    AuthenticationProof, BbsCredential, Changes, Contact, Credential, CredentialAttribute,
+    CredentialFragment1, CredentialFragment2, CredentialOffer, CredentialPresentation,
+    CredentialProof, CredentialPublicKey, CredentialRequest, CredentialSchema, EntityCredential,
+    OfferId, PresentationManifest, ProfileChangeEvent, ProfileIdentifier, ProofRequestId,
 };
 use ockam_core::{Address, Route};
 use serde::{Deserialize, Serialize};
@@ -14,7 +14,7 @@ pub type Id = ProfileIdentifier;
 
 #[derive(Clone, Serialize, Deserialize)]
 pub enum IdentityRequest {
-    CreateProfile,
+    CreateProfile(Address),
     CreateAuthenticationProof(Id, ByteVec),
     CreateKey(Id, String),
     GetProfilePublicKey(Id),
@@ -48,8 +48,8 @@ pub enum IdentityRequest {
     ),
     AcceptCredentialOffer(Id, CredentialOffer, CredentialPublicKey),
     CombineCredentialFragments(Id, CredentialFragment1, CredentialFragment2),
-    IsValidCredential(Id, Credential, CredentialPublicKey),
-    PresentCredential(Id, Credential, PresentationManifest, ProofRequestId),
+    IsValidCredential(Id, BbsCredential, CredentialPublicKey),
+    PresentCredential(Id, BbsCredential, PresentationManifest, ProofRequestId),
     CreateProofRequestId(Id),
     VerifyProofOfPossession(Id, CredentialPublicKey, CredentialProof),
     VerifyCredentialPresentation(
@@ -58,4 +58,6 @@ pub enum IdentityRequest {
         PresentationManifest,
         ProofRequestId,
     ),
+    AddCredential(Id, EntityCredential),
+    GetCredential(Id, Credential),
 }
